@@ -6,7 +6,7 @@
  *	@author		Masaki Fujimoto <fujimoto@php.net>
  *	@license	http://www.opensource.org/licenses/bsd-license.php The BSD License
  *	@package	Ethna
- *	@version	$Id: Ethna_Util.php,v 1.6 2004/12/23 06:03:12 fujimoto Exp $
+ *	@version	$Id: Ethna_Util.php,v 1.14 2006/03/13 11:11:11 fujimoto Exp $
  */
 
 // {{{ to_array
@@ -43,6 +43,61 @@ function is_error($name)
 }
 // }}}
 
+// {{{ file_exists_ex
+/**
+ *	Х桼ƥƥؿ: include_path򸡺Ĥfile_exists()
+ *
+ *	@param	string	$path               ե̾
+ *	@param	bool    $use_include_path   include_pathå뤫ɤ
+ *	@return	bool	true:ͭ false:̵
+ */
+function file_exists_ex($path, $use_include_path = true)
+{
+    if ($use_include_path == false) {
+        return file_exists($path);
+    }
+
+    // check if absolute
+    if (is_absolute_path($path)) {
+        return file_exists($path);
+    }
+
+    $include_path_list = explode(PATH_SEPARATOR, get_include_path());
+    if (is_array($include_path_list) == false) {
+        return file_exists($path);
+    }
+
+    foreach ($include_path_list as $include_path) {
+        if (file_exists($include_path . DIRECTORY_SEPARATOR . $path)) {
+            return true;
+        }
+    }
+    return false;
+}
+// }}}
+
+// {{{ is_absolute_path
+/**
+ *	Х桼ƥƥؿ: Хѥɤ֤
+ *
+ *	@param	string	$path               ե̾
+ *	@return	bool	true: false:
+ */
+function is_absolute_path($path)
+{
+    if (OS_WINDOWS) {
+        if (preg_match('/^[a-z]:/i', $path) && $path{2} == DIRECTORY_SEPARATOR) {
+            return true;
+        }
+    } else {
+        if ($path{0} == DIRECTORY_SEPARATOR) {
+            return true;
+        }
+    }
+    return false;
+}
+// }}}
+
 // {{{ Ethna_Util
 /**
  *	桼ƥƥ饹
@@ -76,11 +131,12 @@ class Ethna_Util
 		Ethna_Util::purgeTmp("uniqid_", 60*60*1);
 
 		$filename = sprintf("%s/uniqid_%s_%s", $c->getDirectory('tmp'), $_SERVER['REMOTE_ADDR'], $uniqid);
-		$st = @stat($filename);
-		if ($st == false) {
+		if (file_exists($filename) == false) {
 			touch($filename);
 			return false;
 		}
+
+		$st = stat($filename);
 		if ($st[9] + 60*60*1 < time()) {
 			// too old
 			return false;
@@ -125,7 +181,7 @@ class Ethna_Util
 	 */
 	function checkMailAddress($mailaddress)
 	{
-		if (preg_match('/^([a-z0-9_]|\-|\.|\+)+@(([a-z0-9_]|\-)+\.)+[a-z]{2,4}$/i', $mailaddress)) {
+		if (preg_match('/^([a-z0-9_]|\-|\.|\+)+@(([a-z0-9_]|\-)+\.)+[a-z]{2,6}$/i', $mailaddress)) {
 			return true;
 		}
 		return false;
@@ -274,12 +330,33 @@ class Ethna_Util
 			if (is_array($vars[$name])) {
 				$retval[$name] = array();
 				Ethna_Util::_escapeHtml($vars[$name], $retval[$name]);
-			} else {
-				$retval[$name] = htmlspecialchars($vars[$name]);
+			} else if (!is_object($vars[$name])) {
+				$retval[$name] = htmlspecialchars($vars[$name], ENT_QUOTES);
 			}
 		}
 	}
 
+	/**
+	 *	ʸMIME󥳡ɤ
+	 *
+	 *	@access	public
+	 *	@param	string	$string		MIME󥳡ɤʸ
+	 *	@return	󥳡ɺѤߤʸ
+	 */
+	function encode_MIME($string)
+	{
+		$pos = 0;
+		$split = 36;
+		$_string = "";
+		while ($pos < mb_strlen($string))
+		{
+			$tmp = mb_strimwidth($string, $pos, $split, "");
+			$pos += mb_strlen($tmp);
+			$_string .= (($_string)? ' ' : '') . mb_encode_mimeheader($tmp, 'ISO-2022-JP');
+		}
+		return $_string;
+	}
+
 	/**
 	 *	Google󥯥ꥹȤ֤
 	 *
@@ -505,7 +582,7 @@ class Ethna_Util
 
         if (DIRECTORY_SEPARATOR == '/' && (substr($path, 0, 1) == '/' OR substr($path, 0, 1) == '~')) {
             return true;
-        } elseif (DIRECTORY_SEPARATOR == '\\' && preg_match('/^[a-z]:\\\/i', $path)) {
+        } else if (DIRECTORY_SEPARATOR == '\\' && preg_match('/^[a-z]:\\\/i', $path)) {
             return true;
         }
 
