@@ -6,7 +6,7 @@
  *	@author		Masaki Fujimoto <fujimoto@php.net>
  *	@license	http://www.opensource.org/licenses/bsd-license.php The BSD License
  *	@package	Ethna
- *	@version	$Id: Ethna_SOAP_Gateway.php,v 1.2 2004/12/16 17:59:36 fujimoto Exp $
+ *	@version	$Id: Ethna_SOAP_Gateway.php,v 1.3 2005/01/06 17:44:23 fujimoto Exp $
  */
 
 // {{{ Ethna_SOAP_Gateway
@@ -23,9 +23,7 @@ class Ethna_SOAP_Gateway
 	 *	@access	private
 	 */
 
-	/**
-	 *	@var	object	Ethna_Controller	controller֥
-	 */
+	/**	@var	object	Ethna_Controller	controller֥ */
 	var	$controller;
 
 	/**#@-*/
