@@ -2,15 +2,15 @@
 /**
  *	{$action_path}
  *
- *	@author		your name
+ *	@author		{$author}
  *	@package	{$project_id}
- *	@version	$Id: skel.action.php,v 1.4 2005/01/04 12:53:26 fujimoto Exp $
+ *	@version	$Id: skel.action.php,v 1.7 2006/03/23 13:16:37 fujimoto Exp $
  */
 
 /**
  *	{$action_name}եμ
  *
- *	@author		your name
+ *	@author		{$author}
  *	@access		public
  *	@package	{$project_id}
  */
@@ -30,7 +30,7 @@ class {$action_form} extends Ethna_ActionForm
 			'regexp'        => null,			// ʸ(ɽ)
 			'custom'        => null,			// ᥽åɤˤå
 			'filter'        => null,			// Ѵե륿ץ
-			'form_type'		=> FORM_TYPE_TEXT	// ե෿
+			'form_type'     => FORM_TYPE_TEXT,	// ե෿
 			'type'          => VAR_TYPE_INT,	// ͷ
 		),
 		*/
@@ -40,7 +40,7 @@ class {$action_form} extends Ethna_ActionForm
 /**
  *	{$action_name}μ
  *
- *	@author		your name
+ *	@author		{$author}
  *	@access		public
  *	@package	{$project_id}
  */
