@@ -1,20 +1,20 @@
 <?php
 /**
- *	{$view_path}.php
+ *	{$view_path}
  *
+ *	@author		{$author}
  *	@package	{$project_id}
- *
- *	$Id: skel.view.php,v 1.2 2004/12/09 02:58:24 fujimoto Exp $
+ *	@version	$Id: skel.view.php,v 1.6 2006/03/07 16:23:18 fujimoto Exp $
  */
 
 /**
  *	{$forward_name}ӥ塼μ
  *
- *	@author		yourname
+ *	@author		{$author}
  *	@access		public
  *	@package	{$project_id}
  */
-class {$project_id}_View_{$view_name} extends Ethna_ViewClass
+class {$view_class} extends Ethna_ViewClass
 {
 	/**
 	 *	
